==> haskell-lifted-base-0.2.3.12-269-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lifted-base
version:              0.2.3.12
visibility:           public
id:                   lifted-base-0.2.3.12-LPwBSk7hxRfLQ1PzpNPxYn
key:                  lifted-base-0.2.3.12-LPwBSk7hxRfLQ1PzpNPxYn
license:              BSD-3-Clause
copyright:            (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/lifted-base
synopsis:             lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.

    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.

category:             Control
abi:                  1a7e72df5358346517c989af6ca4c337
exposed:              True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lifted-base-0.2.3.12
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-base
hs-libraries:         HSlifted-base-0.2.3.12-LPwBSk7hxRfLQ1PzpNPxYn
includes:             inlinable.h
depends:
    base-4.16.4.0 monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK
    transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN

haddock-interfaces:   /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html:         /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.12-297.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-base
version:              0.2.3.12
visibility:           public
id:                   lifted-base-0.2.3.12-4lqeQZi6Is2ElxL17hUAIJ
key:                  lifted-base-0.2.3.12-4lqeQZi6Is2ElxL17hUAIJ
license:              BSD-3-Clause
copyright:            (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/lifted-base
synopsis:             lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.

    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.

category:             Control
abi:                  d2695b42bbb5cc41761f979fd09e2b58
exposed:              True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-base
hs-libraries:         HSlifted-base-0.2.3.12-4lqeQZi6Is2ElxL17hUAIJ
includes:             inlinable.h
depends:
    base-4.17.2.1 monad-control-1.0.3.1-CU0oSebqH0K53geyhZCKTM
    transformers-base-0.4.6-Gpx2WMc051hBRdn2HnKilA

haddock-interfaces:   /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html:         /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
